package ar.edu.unju.fi.poo.champions.controller;

import ar.edu.unju.fi.poo.champions.service.SoccerService;
import ar.edu.unju.fi.poo.champions.service.dto.request.PlayerDTO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.dao.DataAccessException;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;
import java.util.NoSuchElementException;

/**
 * 
 * @author jzapana
 *
 */
@RestController
@RequestMapping("/api/v2/player")
@Slf4j
public class PlayerResource {

	SoccerService soccerService;
	public PlayerResource(SoccerService soccerService) {
		this.soccerService = soccerService;
	}

	@PostMapping("/players")
	public ResponseEntity<?> savePlayerToTeam(@RequestBody PlayerDTO dto) {
		log.debug("Adding player to team [{}]", dto.getTeamId());
		Map<String, Object> response = new HashMap();
		try {
			response.put("player", soccerService.addPlayerToTeam(dto));
			response.put("Message", "Object created successfully");
			return ResponseEntity.status(HttpStatus.CREATED).body(response);
		} catch (DataAccessException e) {
			log.error("Error saving player to team [{}]: {}", dto.getTeamId(), e.getMessage());
			response.put("Mensaje", "Error saving player");
			response.put("Error", e.getMostSpecificCause().getMessage());
			return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(response);
		}
	}

	@PutMapping("/players")
	public ResponseEntity<?> updatePlayerToTeam(@RequestBody PlayerDTO dto) {
		log.debug("Updating player in team [{}]", dto.getTeamId());
		Map<String, Object> response = new HashMap();
		try {
			PlayerDTO player = soccerService.updatePlayer(dto);
			response.put("Player", player);
			response.put("Message", "Object modified successfully");
			return ResponseEntity.ok(response);
		} catch (NoSuchElementException e) {
			log.warn("Player not found for update in team [{}]: {}", dto.getTeamId(), e.getMessage());
			response.put("Message", "Player ID not found");
			return ResponseEntity.status(HttpStatus.NOT_FOUND).body(response);
		} catch (DataAccessException e) {
			log.error("Database error while updating player in team [{}]: {}", dto.getTeamId(), e.getMessage());
			response.put("Message", "Error updating player");
			response.put("Error", e.getMostSpecificCause().getMessage());
			return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(response);
		}
	}

}
